==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/ts/File_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Ferramentas de Arquivo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Exiba ferramentas de arquivo</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Arquivo</translatorcomment>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <location line="+63"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Formato:
Formato:</translatorcomment>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: Save_pt.ts--
Substituir arquivo?
Arquivo existe:
&apos;%1&apos;
Substituir arquivo?</translatorcomment>
        <translation>Substitua o Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_pt.ts--
O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translatorcomment>
        <translation>O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/ts/File_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Ferramentas de Arquivo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Exiba ferramentas de arquivo</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Arquivo</translatorcomment>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Formato:
Formato:</translatorcomment>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: Save_pt.ts--
Substituir arquivo?
Arquivo existe:
&apos;%1&apos;
Substituir arquivo?</translatorcomment>
        <translation>Substitua o Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_pt.ts--
O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translatorcomment>
        <translation>O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Todos os arquivos</translation>
    </message>
</context>
</TS>
